<?php
  
  class db {
  /* This class is an abstraction class for the database used. Initially it was
   * written for the gnucomo-project to support PostgreSQL, but ultimately 
   * it must be ready to be used with other database systems as well. The code
   * will then be used to over come the specific differences between systems
   */

   //Input variables
   var $db_host;            //The host-name (or IP-address) to make the connection to
   var $db_name;            //The name of the database
   var $db_user;            //The username as known in the database
   var $db_password;        //The password used for entry

   //Database information
   var $db_connection;     //The active database connection
   var $db_result;         //The result-set from a query
   var $db_row_number;	   //The row-number that is currently active
   var $db_result_row;	   //Array with in each element a field of the result

   function db_connect ($connection_string)
   {
    /* This function makes the connection to the database. It will look at the selected DBMS. 
     * It will detected if password or hostname is missing and leave that out of the string.
     * INPUT: NONE (The database connection string)
     * OUTPUT: NONE
     */ 
    
	$this->db_connection = pg_pconnect($connection_string);

	if ($this->have_db_connection() == FALSE)
        {
	   syslog (LOG_INFO, "Failed to make a connection to Postgres");
           die ("connection to Postgres failed\n");
	}
        else
        {
	   syslog (LOG_INFO, "Connection to Postgres was made correctly");
	}
   }
	    
   function have_db_connection () {
   /* This simple function verifies if a connection has succesfully been made
    * Output: Returns TRUE if the connection was successfully (else it will be FALSE)
    */
   // PHP-> 4.2.Xcode  if (pg_connection_status($this->db_connection) == PGSQL_CONNECTION_BAD) {
   if ($this->db_connection == '') {
       return "FALSE";
    } else {
       return "TRUE";
    }
   }
   
   function query ($inp_sql_query) {

   /* This function executes a query against the active database connection
    * INPUT:
    *   - $inp_sql_query: The is the string with the SQL to execute
    * OUTPUT: Resultstring
    */
	$this->db_result =  pg_exec ($this->db_connection, $inp_sql_query);
        $this->db_row_number = 0;

        return $this->db_result;
    }

    function fetch_row() {
    /* This function returns a single row as a result of a query if the last record has been reached
     * the result will be FALSE otherwise it will be TRUE
     * INPUT      : NONE (everything is available within the class)
     * OUTPUT     : Success TRUE/FALSE 
     * VALUES SET :  
     */
     unset ($this->db_result_row);
     if (pg_numrows($this->db_result) < $this->db_row_number) {
        $this->db_row_number=-1;
        return "FALSE";
     }  else {
        $this->db_result_row = pg_fetch_row($this->db_result);
        return "TRUE";
     }
    } 

    function fetch_object($result, $row)
    {
       return pg_fetch_object($result, $row);
    }

    function num_rows($db_result = 0) {
    /* This functions returns the number of rows in a resultset
     * INPUT     : Postgres result index (default = internal result)..
     * OUTPUT    : Number of rows (number)
     */

     if ($db_result == 0)
     {
        //  Default: use result from inside the object.

        $db_result = $this->db_result;
     }
     return pg_numrows($db_result);

     // 4.2.X return pg_num_rows($this->db_result);
    }

    function num_fields() {
    /* This function returns the number of fields in the resultset
     * INPUT    : NONE
     * OUTPUT   : Number of fields (number)
     */
     return pg_numfields($this->db_result);
     //4.2.X return pg_num_fields($this->db_result);
    }

}

?>
